@@ -178,6 +178,8 @@ DFLT_IMPORT_NAME_WHITELIST = [
     'requests', 'serial', 'simplejson', 'six', 'suds',
     'unittest2', 'urllib3', 'usb', 'vatnumber', 'vobject', 'werkzeug',
     'wsgiref', 'xlsxwriter', 'xlwt', 'yaml',
+    # OpenUpgrade migration
+    'openupgradelib'
 ]
 DFTL_JSLINTRC = os.path.join(
     os.path.dirname(os.path.dirname(os.path.realpath(__file__))),
